@@ -229,43 +229,43 @@ setGeneric("getProb", function(obj) standardGeneric("getProb"))
 #' @param rs vector of a randomization sequence that should be highlighted.
 #' 
 #' @export
-plotSeq <- function(sequences,plotAllSeq=F,emph=NA,rs=NA){ 
-  N<-N(sequences)
+plotSeq <- function(sequences, plotAllSeq = FALSE, emph = NA, rs = NA){ 
+  N <- N(sequences)
   
   plot.new()
-  plot.window(xlim=c(0,N), ylim=c(-N,N))
-  abline(a=0, b=0, col="lightgray")
+  plot.window(xlim = c(0, N), ylim = c(-N, N))
+  abline(a = 0, b = 0, col="lightgray")
   axis(1)
   axis(2)
   axis(4)
   #title(main = "Randomization Sequences")
-  title(ylab="Difference in group size")
-  title(xlab=expression(paste("Patient ", i)))
+  title(ylab = "Difference in group size")
+  title(xlab = expression(paste("Patient ", i)))
   box()
   
-  if(plotAllSeq){
-    for(i in 0:(N-1)){
-      for(j in seq(-i,i,2)){
-        lines(c(i,i+1),c(j,j+1),type="b",col="lightgray")
-        lines(c(i,i+1),c(j,j-1),type="b",col="lightgray")
+  if (plotAllSeq) {
+    for (i in 0:(N-1)) {
+      for (j in seq(-i,i,2)) {
+        lines(c(i, i+1), c(j, j+1), type = "b", col = "lightgray")
+        lines(c(i, i+1), c(j, j-1), type = "b", col = "lightgray")
       }
     }
   }
   
-  numberOfSequences<-nrow(sequences@M)
-  if (!is.na(emph)) stopifnot(emph<numberOfSequences, 0<emph)
+  numberOfSequences <- nrow(sequences@M)
+  if (!is.na(emph)) stopifnot(emph < numberOfSequences, 0 < emph)
   
-  for(i in 1:numberOfSequences){
-    lines(0:N,cumsum(c(0,2*(sequences@M)[i,]-1)),type="b")
+  for (i in 1:numberOfSequences) {
+    lines(0:N, cumsum(c(0,2*(sequences@M)[i,]-1)), type = "b")
   }
   
   if(!is.na(emph)){
-    lines(0:N,cumsum(c(0,2*sequences@M[emph,]-1)),type="b",lwd=2, col="cornflowerblue")
+    lines(0:N, cumsum(c(0,2*sequences@M[emph,]-1)), type = "b",lwd = 2, col = "cornflowerblue")
   }
-  else if (!anyNA(rs)){
-    f<-c("black","red")
-    D<-c(0,cumsum(2*as.numeric(rs)-1)) # contains the random walk
-    lines(0:N,D,type="b",lwd=2)
+  else if (!anyNA(rs)) {
+    f<-c("black", "red")
+    D<-c(0, cumsum(2*as.numeric(rs)-1)) # contains the random walk
+    lines(0:N, D, type = "b", lwd=2)
   }
 }
 
